@@ -9,7 +9,7 @@ package Image::TIFF;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.09';
+$VERSION = '1.10';
 
 my @types = (
   [ "BYTE",      "C1", 1],
@@ -966,7 +966,7 @@ sub add_fields
 		$maker =~ /^([A-Z]+)/; $maker = $1 || ''; # "OLYMPUS ..." > "OLYMPUS"
 
 		# if 'Panasonic' doesn't exist, try 'Panasonic DMC-FZ5'
-		$maker = $self->{Make}.' '.$self->{Model}
+		$maker = join " " => grep m/\S/ => $self->{Make}, $self->{Model}
 		    unless exists $makernotes{$maker};
 
 		if (exists $makernotes{$maker}) {
